@@ -79,15 +79,15 @@ void ResourceDirConfig::loadSettings( KRES::Resource *res )
   ResourceDir *resource = dynamic_cast<ResourceDir*>( res );
 
   if ( !resource ) {
-    kDebug(5700) << "ResourceDirConfig::loadSettings(): cast failed";
+    kDebug() << "cast failed";
     return;
   }
 
   mFormatBox->setCurrentIndex( mFormatTypes.indexOf( resource->format() ) );
 
-  mFileNameEdit->setPath( resource->path() );
+  mFileNameEdit->setUrl( resource->path() );
   if ( mFileNameEdit->url().isEmpty() ) {
-    mFileNameEdit->setPath( KABC::StdAddressBook::directoryName() );
+    mFileNameEdit->setUrl( KABC::StdAddressBook::directoryName() );
   }
 }
 
@@ -96,7 +96,7 @@ void ResourceDirConfig::saveSettings( KRES::Resource *res )
   ResourceDir *resource = dynamic_cast<ResourceDir*>( res );
 
   if ( !resource ) {
-    kDebug(5700) << "ResourceDirConfig::loadSettings(): cast failed";
+    kDebug() << "cast failed";
     return;
   }
 
