@@ -3,7 +3,7 @@
 
   Copyright (c) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
   Copyright (c) 2006-2007 Christian Weilbach <christian_weilbach@web.de>
-  Copyright (c) 2007 Mike Arthur <mike@mikearthur.co.uk>
+  Copyright (c) 2007-2008 Mike Arthur <mike@mikearthur.co.uk>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -40,20 +40,20 @@ using namespace KBlog;
 Blogger1::Blogger1( const KUrl &server, QObject *parent )
   : Blog( server, *new Blogger1Private, parent )
 {
-  kDebug(5323) << "Blogger1()";
+  kDebug() << "Blogger1()";
   setUrl( server );
 }
 
 Blogger1::Blogger1( const KUrl &server, Blogger1Private &dd, QObject *parent )
   : Blog( server, dd, parent )
 {
-  kDebug(5323) << "Blogger1()";
+  kDebug() << "Blogger1()";
   setUrl( server );
 }
 
 Blogger1::~Blogger1()
 {
-  kDebug(5323) << "~Blogger1()";
+  kDebug() << "~Blogger1()";
 }
 
 QString Blogger1::interfaceName() const
@@ -73,7 +73,7 @@ void Blogger1::setUrl( const KUrl &server )
 void Blogger1::fetchUserInfo()
 {
     Q_D( Blogger1 );
-    kDebug(5323) << "Fetch user's info...";
+    kDebug() << "Fetch user's info...";
     QList<QVariant> args( d->blogger1Args() );
     d->mXmlRpcClient->call(
       "blogger.getUserInfo", args,
@@ -84,7 +84,7 @@ void Blogger1::fetchUserInfo()
 void Blogger1::listBlogs()
 {
     Q_D( Blogger1 );
-    kDebug(5323) << "Fetch List of Blogs...";
+    kDebug() << "Fetch List of Blogs...";
     QList<QVariant> args( d->blogger1Args() );
     d->mXmlRpcClient->call(
       "blogger.getUsersBlogs", args,
@@ -95,7 +95,7 @@ void Blogger1::listBlogs()
 void Blogger1::listRecentPosts( int number )
 {
     Q_D( Blogger1 );
-    kDebug(5323) << "Fetching List of Posts...";
+    kDebug() << "Fetching List of Posts...";
     QList<QVariant> args( d->defaultArgs( blogId() ) );
     args << QVariant( number );
     d->mXmlRpcClient->call(
@@ -108,12 +108,12 @@ void Blogger1::listRecentPosts( int number )
 void Blogger1::fetchPost( KBlog::BlogPost *post )
 {
   if ( !post ) {
-    kError(5323) << "Blogger1::modifyPost: post is null pointer";
+    kError() << "Blogger1::modifyPost: post is null pointer";
     return;
   }
 
   Q_D( Blogger1 );
-  kDebug(5323) << "Fetching Post with url" << post->postId();
+  kDebug() << "Fetching Post with url" << post->postId();
   QList<QVariant> args( d->defaultArgs( post->postId() ) );
   unsigned int i= d->mCallCounter++;
   d->mCallMap[ i ] = post;
@@ -129,11 +129,11 @@ void Blogger1::modifyPost( KBlog::BlogPost *post )
   Q_D( Blogger1 );
 
   if ( !post ) {
-    kError(5323) << "Blogger1::modifyPost: post is null pointer";
+    kError() << "Blogger1::modifyPost: post is null pointer";
     return;
   }
 
-  kDebug(5323) << "Uploading Post with postId" << post->postId();
+  kDebug() << "Uploading Post with postId" << post->postId();
   unsigned int i= d->mCallCounter++;
   d->mCallMap[ i ] = post;
   QList<QVariant> args( d->defaultArgs( post->postId() ) );
@@ -150,13 +150,13 @@ void Blogger1::createPost( KBlog::BlogPost *post )
   Q_D( Blogger1 );
 
   if ( !post ) {
-    kError(5323) << "Blogger1::createPost: post is null pointer";
+    kError() << "Blogger1::createPost: post is null pointer";
     return;
   }
 
   unsigned int i= d->mCallCounter++;
   d->mCallMap[ i ] = post;
-  kDebug(5323) << "Creating new Post with blogid" << blogId();
+  kDebug() << "Creating new Post with blogid" << blogId();
   QList<QVariant> args( d->defaultArgs( blogId() ) );
   d->readArgsFromPost( &args, *post );
   d->mXmlRpcClient->call(
@@ -171,13 +171,13 @@ void Blogger1::removePost( KBlog::BlogPost *post )
   Q_D( Blogger1 );
 
   if ( !post ) {
-    kError(5323) << "Blogger1::removePost: post is null pointer";
+    kError() << "Blogger1::removePost: post is null pointer";
     return;
   }
 
  unsigned int i = d->mCallCounter++;
  d->mCallMap[ i ] = post;
- kDebug(5323) << "Blogger1::removePost: postId=" << post->postId();
+ kDebug() << "Blogger1::removePost: postId=" << post->postId();
  QList<QVariant> args( d->blogger1Args( post->postId() ) );
  args << QVariant( true ); // Publish must be set to remove post.
  d->mXmlRpcClient->call(
@@ -195,12 +195,13 @@ mXmlRpcClient(0)
 
 Blogger1Private::~Blogger1Private()
 {
-  kDebug(5323) << "~Blogger1Private()";
+  kDebug() << "~Blogger1Private()";
   delete mXmlRpcClient;
 }
 
 QList<QVariant> Blogger1Private::defaultArgs( const QString &id )
 {
+  kDebug();
   Q_Q ( Blogger1 );
   QList<QVariant> args;
   args << QVariant( QString( "0123456789ABCDEF" ) );
@@ -215,7 +216,8 @@ QList<QVariant> Blogger1Private::defaultArgs( const QString &id )
 // reimplemenet defaultArgs, since we may not use it virtually everywhere
 QList<QVariant> Blogger1Private::blogger1Args( const QString &id )
 {
-  Q_Q( Blogger1 );
+  kDebug();
+  Q_Q ( Blogger1 );
   QList<QVariant> args;
   args << QVariant( QString( "0123456789ABCDEF" ) );
   if( !id.isEmpty() ) {
@@ -231,26 +233,26 @@ void Blogger1Private::slotFetchUserInfo( const QList<QVariant> &result, const QV
   Q_Q( Blogger1 );
   Q_UNUSED( id );
 
-  kDebug(5323) << "Blog::slotFetchUserInfo";
-  kDebug(5323) << "TOP:" << result[0].typeName();
+  kDebug() << "Blog::slotFetchUserInfo";
+  kDebug() << "TOP:" << result[0].typeName();
   QMap<QString,QString> userInfo;
   if ( result[0].type() != QVariant::Map ) {
-    kError(5323) << "Could not fetch user's info out of the result from the server,"
+    kError() << "Could not fetch user's info out of the result from the server,"
                  << "not a map.";
     emit q->error( Blogger1::ParsingError,
                         i18n( "Could not fetch user's info out of the result "
                               "from the server, not a map." ) );
-  } else {
-    const QMap<QString,QVariant> resultMap = result[0].toMap();
-    userInfo["nickname"]=resultMap["nickname"].toString();
-    userInfo["userid"]=resultMap["userid"].toString();
-    userInfo["url"]=resultMap["url"].toString();
-    userInfo["email"]=resultMap["email"].toString();
-    userInfo["lastname"]=resultMap["lastname"].toString();
-    userInfo["firstname"]=resultMap["firstname"].toString();
-
-    emit q->fetchedUserInfo( userInfo );
+    return;
   }
+  const QMap<QString,QVariant> resultMap = result[0].toMap();
+  userInfo["nickname"]=resultMap["nickname"].toString();
+  userInfo["userid"]=resultMap["userid"].toString();
+  userInfo["url"]=resultMap["url"].toString();
+  userInfo["email"]=resultMap["email"].toString();
+  userInfo["lastname"]=resultMap["lastname"].toString();
+  userInfo["firstname"]=resultMap["firstname"].toString();
+
+  emit q->fetchedUserInfo( userInfo );
 }
 
 void Blogger1Private::slotListBlogs( const QList<QVariant> &result, const QVariant &id )
@@ -258,31 +260,31 @@ void Blogger1Private::slotListBlogs( const QList<QVariant> &result, const QVaria
   Q_Q( Blogger1 );
   Q_UNUSED( id );
 
-  kDebug(5323) << "Blog::slotListBlogs";
-  kDebug(5323) << "TOP:" << result[0].typeName();
+  kDebug() << "Blog::slotListBlogs";
+  kDebug() << "TOP:" << result[0].typeName();
   QList<QMap<QString,QString> > blogsList;
   if ( result[0].type() != QVariant::List ) {
-    kError(5323) << "Could not fetch blogs out of the result from the server,"
+    kError() << "Could not fetch blogs out of the result from the server,"
                  << "not a list.";
     emit q->error( Blogger1::ParsingError,
                         i18n( "Could not fetch blogs out of the result "
                               "from the server, not a list." ) );
-  } else {
-    const QList<QVariant> posts = result[0].toList();
-    QList<QVariant>::ConstIterator it = posts.begin();
-    QList<QVariant>::ConstIterator end = posts.end();
-    for ( ; it != end; ++it ) {
-      kDebug(5323) << "MIDDLE:" << ( *it ).typeName();
-      const QMap<QString, QVariant> postInfo = ( *it ).toMap();
-      QMap<QString,QString> blogInfo;
-      blogInfo[ "id" ] = postInfo["blogid"].toString();
-      blogInfo[ "name" ] = postInfo["blogName"].toString();
-      kDebug(5323) << "Blog information retrieved: ID =" << blogInfo["id"]
-          << ", Name =" << blogInfo["name"];
-      blogsList << blogInfo;
-    }
-    emit q->listedBlogs( blogsList );
+    return;
   }
+  const QList<QVariant> posts = result[0].toList();
+  QList<QVariant>::ConstIterator it = posts.begin();
+  QList<QVariant>::ConstIterator end = posts.end();
+  for ( ; it != end; ++it ) {
+    kDebug() << "MIDDLE:" << ( *it ).typeName();
+    const QMap<QString, QVariant> postInfo = ( *it ).toMap();
+    QMap<QString,QString> blogInfo;
+    blogInfo[ "id" ] = postInfo["blogid"].toString();
+    blogInfo[ "name" ] = postInfo["blogName"].toString();
+    kDebug() << "Blog information retrieved: ID =" << blogInfo["id"]
+        << ", Name =" << blogInfo["name"];
+    blogsList << blogInfo;
+  }
+  emit q->listedBlogs( blogsList );
 }
 
 void Blogger1Private::slotListRecentPosts( const QList<QVariant> &result, const QVariant &id )
@@ -291,48 +293,48 @@ void Blogger1Private::slotListRecentPosts( const QList<QVariant> &result, const
   int count = id.toInt(); // not sure if needed, actually the API should
 // not give more posts
 
-  kDebug(5323) << "Blog::slotListRecentPosts";
-  kDebug(5323) << "TOP:" << result[0].typeName();
+  kDebug() << "Blog::slotListRecentPosts";
+  kDebug() << "TOP:" << result[0].typeName();
 
   QList <BlogPost> fetchedPostList;
 
   if ( result[0].type() != QVariant::List ) {
-    kError(5323) << "Could not fetch list of posts out of the"
+    kError() << "Could not fetch list of posts out of the"
                  << "result from the server, not a list.";
     emit q->error( Blogger1::ParsingError,
                    i18n( "Could not fetch list of posts out of the result "
                          "from the server, not a list." ) );
-  } else {
-    const QList<QVariant> postReceived = result[0].toList();
-    QList<QVariant>::ConstIterator it = postReceived.begin();
-    QList<QVariant>::ConstIterator end = postReceived.end();
-    for ( ; it != end; ++it ) {
-      BlogPost post;
-      kDebug(5323) << "MIDDLE:" << ( *it ).typeName();
-      const QMap<QString, QVariant> postInfo = ( *it ).toMap();
-      if ( readPostFromMap( &post, postInfo ) ) {
-        kDebug(5323) << "Post with ID:"
-                     << post.postId()
-                     << "appended in fetchedPostList";
-        post.setStatus( BlogPost::Fetched );
-        fetchedPostList.append( post );
-      } else {
-        kError(5323) << "readPostFromMap failed!";
-        emit q->error( Blogger1::ParsingError, i18n( "Could not read post." ) );
-      }
-      if ( --count == 0 ) {
-        break;
-      }
+    return;
+  }
+  const QList<QVariant> postReceived = result[0].toList();
+  QList<QVariant>::ConstIterator it = postReceived.begin();
+  QList<QVariant>::ConstIterator end = postReceived.end();
+  for ( ; it != end; ++it ) {
+    BlogPost post;
+    kDebug() << "MIDDLE:" << ( *it ).typeName();
+    const QMap<QString, QVariant> postInfo = ( *it ).toMap();
+    if ( readPostFromMap( &post, postInfo ) ) {
+      kDebug() << "Post with ID:"
+                    << post.postId()
+                    << "appended in fetchedPostList";
+      post.setStatus( BlogPost::Fetched );
+      fetchedPostList.append( post );
+    } else {
+      kError() << "readPostFromMap failed!";
+      emit q->error( Blogger1::ParsingError, i18n( "Could not read post." ) );
+    }
+    if ( --count == 0 ) {
+      break;
     }
   }
-  kDebug(5323) << "Emitting listRecentPostsFinished()";
+  kDebug() << "Emitting listRecentPostsFinished()";
   emit q->listedRecentPosts( fetchedPostList );
 }
 
 void Blogger1Private::slotFetchPost( const QList<QVariant> &result, const QVariant &id )
 {
   Q_Q( Blogger1 );
-  kDebug(5323) << "Blog::slotFetchPost";
+  kDebug() << "Blog::slotFetchPost";
 
   KBlog::BlogPost *post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
@@ -340,32 +342,18 @@ void Blogger1Private::slotFetchPost( const QList<QVariant> &result, const QVaria
   //array of structs containing ISO.8601
   // dateCreated, String userid, String postid, String content;
   // TODO: Time zone for the dateCreated!
-  kDebug (5323) << "TOP:" << result[0].typeName();
-  if ( result[0].type() != QVariant::Map ) {
-    kError(5323) << "Could not fetch post out of the result from "
-                  << "the server.";
-    emit q->errorPost( Blogger1::ParsingError,
-                          i18n( "Could not fetch post out of the result "
-                                "from the server." ), post );
-    post->setError( i18n( "Could not fetch post out of the "
-                              "result from the server." ) );
-    post->setStatus( BlogPost::Error );
+  kDebug () << "TOP:" << result[0].typeName();
+  if ( result[0].type() == QVariant::Map && readPostFromMap( post, result[0].toMap() ) ) {
+    kDebug() << "Emitting fetchedPost()";
+    post->setStatus( KBlog::BlogPost::Fetched );
+    emit q->fetchedPost( post );
   } else {
-    const QMap<QString, QVariant> postInfo = result[0].toMap();
-    if ( readPostFromMap( post, postInfo ) ) {
-      kDebug(5323) << "Emitting fetchedPost( post.postId()="
-                   << post->postId() << ");";
-      post->setStatus( BlogPost::Fetched );
-      emit q->fetchedPost( post );
-    } else {
-      kError(5323) << "readPostFromMap failed!";
-      emit q->errorPost( Blogger1::ParsingError,
-                            i18n( "Could not read post." ), post );
-      post->setError( i18n( "Could not read post." ) );
-      post->setStatus( BlogPost::Error );
-    }
+    kError() << "Could not fetch post out of the result from the server.";
+    post->setError( i18n( "Could not fetch post out of the result from the server." ) );
+    post->setStatus( BlogPost::Error );
+    emit q->errorPost( Blogger1::ParsingError,
+                       i18n( "Could not fetch post out of the result from the server." ), post );
   }
-
 }
 
 void Blogger1Private::slotCreatePost( const QList<QVariant> &result, const QVariant &id )
@@ -374,32 +362,31 @@ void Blogger1Private::slotCreatePost( const QList<QVariant> &result, const QVari
   KBlog::BlogPost *post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
 
-  kDebug(5323) << "Blog::slotCreatePost";
+  kDebug() << "Blog::slotCreatePost";
   //array of structs containing ISO.8601
   // dateCreated, String userid, String postid, String content;
   // TODO: Time zone for the dateCreated!
-  kDebug (5323) << "TOP:" << result[0].typeName();
+  kDebug () << "TOP:" << result[0].typeName();
   if ( result[0].type() != QVariant::String && result[0].type() != QVariant::Int ) {
-    kError(5323) << "Could not read the postId, not a string or an integer.";
+    kError() << "Could not read the postId, not a string or an integer.";
     emit q->errorPost( Blogger1::ParsingError,
                           i18n( "Could not read the postId, not a string or an integer." ),
                           post );
-  } else {
-    QString id;
-    if ( result[0].type() == QVariant::String ) {
-      id = result[0].toString();
-    }
-    if ( result[0].type() == QVariant::Int ) {
-      id = QString( "%1" ).arg( result[0].toInt() );
-    }
-    post->setPostId( id );
-    post->setStatus( KBlog::BlogPost::Created );
-    emit q->createdPost( post );
-    kDebug(5323) << "emitting createdPost()"
-                 << "for title: \"" << post->title()
-                 << "\" server id: " << id;
+    return;
   }
-
+  QString serverID;
+  if ( result[0].type() == QVariant::String ) {
+    serverID = result[0].toString();
+  }
+  if ( result[0].type() == QVariant::Int ) {
+    serverID = QString( "%1" ).arg( result[0].toInt() );
+  }
+  post->setPostId( serverID );
+  post->setStatus( KBlog::BlogPost::Created );
+  kDebug() << "emitting createdPost()"
+                << "for title: \"" << post->title()
+                << "\" server id: " << serverID;
+  emit q->createdPost( post );
 }
 
 void Blogger1Private::slotModifyPost( const QList<QVariant> &result, const QVariant &id )
@@ -408,22 +395,22 @@ void Blogger1Private::slotModifyPost( const QList<QVariant> &result, const QVari
   KBlog::BlogPost *post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
 
-  kDebug(5323) << "Blog::slotModifyPost";
+  kDebug() << "Blog::slotModifyPost";
   //array of structs containing ISO.8601
   // dateCreated, String userid, String postid, String content;
   // TODO: Time zone for the dateCreated!
-  kDebug(5323) << "TOP:" << result[0].typeName();
+  kDebug() << "TOP:" << result[0].typeName();
   if ( result[0].type() != QVariant::Bool ) {
-    kError(5323) << "Could not read the result, not a boolean.";
+    kError() << "Could not read the result, not a boolean.";
     emit q->errorPost( Blogger1::ParsingError,
                           i18n( "Could not read the result, not a boolean." ),
                           post );
-  } else {
-    post->setStatus( KBlog::BlogPost::Modified );
-    emit q->modifiedPost( post );
-    kDebug(5323) << "emitting modifiedPost() for title: \""
-                            << post->title() << "\"";
+    return;
   }
+  post->setStatus( KBlog::BlogPost::Modified );
+  kDebug() << "emitting modifiedPost() for title: \""
+      << post->title() << "\"";
+  emit q->modifiedPost( post );
 }
 
 void Blogger1Private::slotRemovePost( const QList<QVariant> &result, const QVariant &id )
@@ -432,21 +419,21 @@ void Blogger1Private::slotRemovePost( const QList<QVariant> &result, const QVari
   KBlog::BlogPost *post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
 
-  kDebug(5323) << "Blog::slotRemovePost";
+  kDebug() << "Blog::slotRemovePost";
   //array of structs containing ISO.8601
   // dateCreated, String userid, String postid, String content;
   // TODO: Time zone for the dateCreated!
-  kDebug(5323) << "TOP:" << result[0].typeName();
+  kDebug() << "TOP:" << result[0].typeName();
   if ( result[0].type() != QVariant::Bool ) {
-    kError(5323) << "Could not read the result, not a boolean.";
+    kError() << "Could not read the result, not a boolean.";
     emit q->errorPost( Blogger1::ParsingError,
                           i18n( "Could not read the result, not a boolean." ),
                           post );
-  } else {
-    post->setStatus( KBlog::BlogPost::Removed );
-    emit q->removedPost( post );
-    kDebug(5323) << "emitting removedPost()";
+    return;
   }
+  post->setStatus( KBlog::BlogPost::Removed );
+  kDebug() << "emitting removedPost()";
+  emit q->removedPost( post );
 }
 
 void Blogger1Private::slotError( int number,
@@ -468,8 +455,8 @@ bool Blogger1Private::readPostFromMap(
     return false;
   }
   QStringList mapkeys = postInfo.keys();
-  kDebug(5323) << endl << "Keys:" << mapkeys.join( ", " );
-  kDebug(5323) << endl;
+  kDebug() << endl << "Keys:" << mapkeys.join( ", " );
+  kDebug() << endl;
 
   KDateTime dt( postInfo["dateCreated"].toDateTime(), KDateTime::UTC );
   if ( dt.isValid() && !dt.isNull() ) {
