@@ -61,21 +61,21 @@ class KCal::Calendar::Private
         mModified( false ),
         mNewObserver( false ),
         mObserversEnabled( true ),
-        mDefaultFilter( new CalFilter ),
-        mFilter( mDefaultFilter )
+        mDefaultFilter( new CalFilter )
     {
-        // Setup default filter, which does nothing
-        mFilter->setEnabled( false );
+      // Setup default filter, which does nothing
+      mFilter = mDefaultFilter;
+      mFilter->setEnabled( false );
 
-        // user information...
-        mOwner.setName( i18n( "Unknown Name" ) );
-        mOwner.setEmail( i18n( "unknown@nowhere" ) );
+      // user information...
+      mOwner.setName( i18n( "Unknown Name" ) );
+      mOwner.setEmail( i18n( "unknown@nowhere" ) );
     }
 
     ~Private()
     {
-        delete mTimeZones;
-        delete mDefaultFilter;
+      delete mTimeZones;
+      delete mDefaultFilter;
     }
     KDateTime::Spec timeZoneIdSpec( const QString &timeZoneId, bool view );
 
@@ -307,6 +307,10 @@ Event::List Calendar::sortEvents( Event::List *eventList,
   case EventSortStartDate:
     alphaList = sortEvents( eventList, EventSortSummary, sortDirection );
     for ( eit = alphaList.begin(); eit != alphaList.end(); ++eit ) {
+      if ( (*eit)->dtStart().isDateOnly() ) {
+        tempList.append( *eit );
+        continue;
+      }
       sortIt = eventListSorted.begin();
       if ( sortDirection == SortDirectionAscending ) {
         while ( sortIt != eventListSorted.end() &&
@@ -321,6 +325,14 @@ Event::List Calendar::sortEvents( Event::List *eventList,
       }
       eventListSorted.insert( sortIt, *eit );
     }
+    if ( sortDirection == SortDirectionAscending ) {
+      // Prepend the list of Events without End DateTimes
+      tempList += eventListSorted;
+      eventListSorted = tempList;
+    } else {
+      // Append the list of Events without End DateTimes
+      eventListSorted += tempList;
+    }
     break;
 
   case EventSortEndDate:
@@ -379,11 +391,11 @@ Event::List Calendar::sortEvents( Event::List *eventList,
 }
 
 Event::List Calendar::events( const QDate &date,
-                              const KDateTime::Spec &timespec,
+                              const KDateTime::Spec &timeSpec,
                               EventSortField sortField,
                               SortDirection sortDirection )
 {
-  Event::List el = rawEventsForDate( date, timespec, sortField, sortDirection );
+  Event::List el = rawEventsForDate( date, timeSpec, sortField, sortDirection );
   d->mFilter->apply( &el );
   return el;
 }
@@ -396,10 +408,10 @@ Event::List Calendar::events( const KDateTime &dt )
 }
 
 Event::List Calendar::events( const QDate &start, const QDate &end,
-                              const KDateTime::Spec &timespec,
+                              const KDateTime::Spec &timeSpec,
                               bool inclusive )
 {
-  Event::List el = rawEvents( start, end, timespec, inclusive );
+  Event::List el = rawEvents( start, end, timeSpec, inclusive );
   d->mFilter->apply( &el );
   return el;
 }
@@ -445,7 +457,11 @@ Incidence *Calendar::dissociateOccurrence( Incidence *incidence,
 
   Incidence *newInc = incidence->clone();
   newInc->recreate();
-  newInc->setRelatedTo( incidence );
+  // Do not call setRelatedTo() when dissociating recurring to-dos, otherwise the new to-do
+  // will appear as a child.  Originally, we planned to set a relation with reltype SIBLING
+  // when dissociating to-dos, but currently kcal only supports reltype PARENT.
+  // We can uncomment the following line when we support the PARENT reltype.
+  //newInc->setRelatedTo( incidence );
   Recurrence *recur = newInc->recurrence();
   if ( single ) {
     recur->clear();
@@ -523,8 +539,8 @@ Incidence *Calendar::incidence( const QString &uid )
 Incidence::List Calendar::incidencesFromSchedulingID( const QString &sid )
 {
   Incidence::List result;
-  Incidence::List incidences = rawIncidences();
-  Incidence::List::iterator it = incidences.begin();
+  const Incidence::List incidences = rawIncidences();
+  Incidence::List::const_iterator it = incidences.begin();
   for ( ; it != incidences.end(); ++it ) {
     if ( (*it)->schedulingID() == sid ) {
       result.append( *it );
@@ -535,8 +551,8 @@ Incidence::List Calendar::incidencesFromSchedulingID( const QString &sid )
 
 Incidence *Calendar::incidenceFromSchedulingID( const QString &UID )
 {
-  Incidence::List incidences = rawIncidences();
-  Incidence::List::iterator it = incidences.begin();
+  const Incidence::List incidences = rawIncidences();
+  Incidence::List::const_iterator it = incidences.begin();
   for ( ; it != incidences.end(); ++it ) {
     if ( (*it)->schedulingID() == UID ) {
       // Touchdown, and the crowd goes wild
@@ -860,8 +876,8 @@ void Calendar::removeRelations( Incidence *incidence )
     }
 
     // now go through all uids that have one entry that point to the incidence
-    for ( QStringList::Iterator uidit = relatedToUids.begin();
-          uidit != relatedToUids.end(); ++uidit ) {
+    for ( QStringList::const_iterator uidit = relatedToUids.constBegin();
+          uidit != relatedToUids.constEnd(); ++uidit ) {
       Incidence::List tempList;
       // Remove all to get access to the remaining entries
       QList<Incidence*> l = d->mOrphans.values( *uidit );
@@ -878,6 +894,18 @@ void Calendar::removeRelations( Incidence *incidence )
       }
     }
   }
+
+  // Make sure the deleted incidence doesn't relate to a non-deleted incidence, since
+  // that would cause trouble in CalendarLocal::close(), as the deleted incidences
+  // are destroyed after the non-deleted incidences. The destructor of the deleted
+  // incidences would then try to access the already destroyed non-deleted incidence,
+  // which would segfault.
+  //
+  // So in short: Make sure dead incidences don't point to alive incidences via the
+  // relation.
+  //
+  // This crash is tested in CalendarLocalTest::testRelationsCrash().
+  incidence->setRelatedTo( 0 );
 }
 
 void Calendar::CalendarObserver::calendarModified( bool modified, Calendar *calendar )
@@ -1134,9 +1162,8 @@ void Calendar::appendRecurringAlarms( Alarm::List &alarms,
               Duration toFromDuration( dt, base );
               int toFrom = toFromDuration.asDays();
               if ( a->snoozeTime().end( from ) <= to ||
-                   toFromDuration.isDaily() && toFrom % snooze == 0 ||
-                   ( toFrom / snooze + 1 ) * snooze <= toFrom + period.asDays() )
-              {
+                   ( toFromDuration.isDaily() && toFrom % snooze == 0 ) ||
+                   ( toFrom / snooze + 1 ) * snooze <= toFrom + period.asDays() ) {
                 found = true;
 #ifndef NDEBUG
                 // for debug output
