@@ -24,7 +24,6 @@
 #include <QtGui/QWidget>
 #include "kcal_export.h"
 
-
 namespace KCal {
 
 class ResourceCached;
@@ -39,7 +38,7 @@ class KCAL_EXPORT ResourceCachedReloadConfig : public QWidget
   Q_OBJECT
   public:
     explicit ResourceCachedReloadConfig( QWidget *parent = 0 );
-
+    ~ResourceCachedReloadConfig();
   public Q_SLOTS:
     void loadSettings( ResourceCached *resource );
     void saveSettings( ResourceCached *resource );
@@ -49,6 +48,7 @@ class KCAL_EXPORT ResourceCachedReloadConfig : public QWidget
 
   private:
     //@cond PRIVATE
+    Q_DISABLE_COPY( ResourceCachedReloadConfig )
     class Private;
     Private *const d;
     //@endcond
@@ -64,6 +64,7 @@ class KCAL_EXPORT ResourceCachedSaveConfig : public QWidget
     Q_OBJECT
   public:
     explicit ResourceCachedSaveConfig( QWidget *parent = 0 );
+    ~ResourceCachedSaveConfig();
 
   public Q_SLOTS:
     void loadSettings( ResourceCached *resource );
@@ -74,6 +75,7 @@ class KCAL_EXPORT ResourceCachedSaveConfig : public QWidget
 
   private:
     //@cond PRIVATE
+    Q_DISABLE_COPY( ResourceCachedSaveConfig )
     class Private;
     Private *const d;
     //@endcond
