@@ -1411,7 +1411,7 @@ bool MailCopiesTo::parse( const char *& scursor, const char * const send,
       return true;
     }
     if ( qstrnicmp( "nobody", scursor, 6 ) == 0 ) {
-      d->alwaysCopy = true;
+      d->neverCopy = true;
       return true;
     }
   }
@@ -1720,12 +1720,14 @@ bool ContentType::isSubtype( const char *subtype ) const
 
 bool ContentType::isText() const
 {
-  return strncasecmp( mediaType().constData(), "text", 4 ) == 0;
+  return ( strncasecmp( mediaType().constData(), "text", 4 ) == 0
+          || isEmpty() );
 }
 
 bool ContentType::isPlainText() const
 {
-  return strcasecmp( mimeType().constData(), "text/plain" ) == 0;
+  return ( strcasecmp( mimeType().constData(), "text/plain" ) == 0
+          || isEmpty() );
 }
 
 bool ContentType::isHTMLText() const
@@ -2101,6 +2103,8 @@ bool Subject::isReply() const
 //@cond PRIVATE
 kmime_mk_trivial_ctor_with_name( ContentDescription,
                                  Generics::Unstructured, Content-Description )
+kmime_mk_trivial_ctor_with_name( ContentLocation,
+                                Generics::Unstructured, Content-Location )
 kmime_mk_trivial_ctor_with_name( From, Generics::MailboxList, From )
 kmime_mk_trivial_ctor_with_name( Sender, Generics::SingleMailbox, Sender )
 kmime_mk_trivial_ctor_with_name( To, Generics::AddressList, To )
